
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.16.3',
    'branch_nick': 'patch-0-Rucio_1_16_3_preparation',
    'revision_id': '7ccd179fe23a0295f84ea530ab3612618b470001',
    'revno': 6659
}
